Name:           pari
Version:        2.5.3
Release:        alt1_2
Summary:        Number Theory-oriented Computer Algebra System
Group:          System/Libraries
# No version is specified
License:        GPL+
URL:            http://pari.math.u-bordeaux.fr/
Source0:        http://pari.math.u-bordeaux.fr/pub/pari/unix/pari-%{version}.tar.gz
Source1:        gp.desktop
Patch0:         pari-2.5.1-xdgopen.patch
Patch1:         pari-2.5.1-optflags.patch
Patch10:        pari-2.5.1-missing-field-init.patch
Patch11:        pari-2.5.3-declaration-not-prototype.patch
Patch12:        pari-2.5.2-clobbered.patch
BuildRequires:  readline-devel
BuildRequires: libgmp-devel libgmp_cxx-devel
BuildRequires: /usr/bin/tex texlive-generic-recommended
BuildRequires: /usr/bin/dvips texlive-generic-recommended
BuildRequires:  desktop-file-utils
BuildRequires:  libX11-devel
BuildRequires:  imake
# Test suite requirements
BuildRequires:  pari-elldata
BuildRequires:  pari-galdata
BuildRequires:  pari-seadata

# Avoid doc-file dependencies and provides
%global __provides_exclude_from ^%{_datadir}/pari/PARI/
%global __requires_exclude_from ^%{_datadir}/pari/PARI/
Source44: import.info

%description
PARI is a widely used computer algebra system designed for fast computations in
number theory (factorizations, algebraic number theory, elliptic curves...),
but also contains a large number of other useful functions to compute with
mathematical entities such as matrices, polynomials, power series, algebraic
numbers, etc., and a lot of transcendental functions.

This package contains the shared libraries. The interactive
calculator PARI/GP is in package pari-gp.

%package devel
Summary:        Header files and libraries for PARI development
Group:          Development/C
Requires:       %{name} = %{version}-%{release}

%description devel
Header files and libraries for PARI development.

%package gp
Summary:        PARI calculator
Group:          Engineering
Requires:       %{name} = %{version}-%{release}
Requires:       bzip2
Requires:       gzip
Requires:       xdg-utils

%description gp
PARI/GP is an advanced programmable calculator, which computes
symbolically as long as possible, numerically where needed, and
contains a wealth of number-theoretic functions.

%prep
%setup -q

# Use xdg-open rather than xdvi to display DVI files (#530565)
%patch0

# Use our optflags, not upstream's
%patch1
sed -i -e 's|@OPTFLAGS@|%{optflags} -Wall -Wextra -Wstrict-prototypes|' config/get_cc

# Fix compiler warnings
# http://pari.math.u-bordeaux.fr/cgi-bin/bugreport.cgi?bug=1316
%patch10
%patch11
%patch12

# Avoid unwanted rpaths
sed -i "s|runpathprefix='.*'|runpathprefix=''|" config/get_ld

%build
./Configure \
    --prefix=%{_prefix} \
    --share-prefix=%{_datadir} \
    --bindir=%{_bindir} \
    --libdir=%{_libdir} \
    --mandir=%{_mandir}/man1 \
    --datadir=%{_datadir}/pari \
    --includedir=%{_includedir} \
    --with-gmp
make %{?_smp_mflags} gp

%install
make install \
  DESTDIR=%{buildroot} \
  INSTALL="install -p" \
  STRIP=/bin/true

# We move pari.cfg to the docdir
rm -fr %{buildroot}%{_prefix}/lib/pari

# Site-wide gprc
mkdir -p %{buildroot}%{_sysconfdir}
install -p -m 644 misc/gprc.dft %{buildroot}%{_sysconfdir}/gprc

# Desktop menu entry
mkdir -p %{buildroot}%{_datadir}/applications
desktop-file-install \
    --vendor fedora \
    --dir %{buildroot}%{_datadir}/applications \
    %{SOURCE1}

# Don't bother installing the simple gp wrapper script, so avoiding the
# need to patch it to fix the path to the executable
find %{buildroot} -name xgp -exec rm '{}' ';'

# Placate rpmlint regarding binary and library permissions
# %{_fixperms} %{buildroot}{%{_bindir},%{_libdir}}

%check
make test-all

%files
%doc AUTHORS CHANGES* COPYING COMPAT NEW README
%doc Olinux-*/pari.cfg
%{_libdir}/libpari-gmp.so.%{version}
%{_libdir}/libpari-gmp.so.3

%files gp
%{_bindir}/gp
%{_bindir}/gp-2.5
%{_bindir}/gphelp
%{_bindir}/tex2mail
%config(noreplace) %{_sysconfdir}/gprc
%dir %{_datadir}/pari/
%doc %{_datadir}/pari/PARI/
%doc %{_datadir}/pari/doc/
%doc %{_datadir}/pari/examples/
%{_datadir}/pari/misc/
%{_datadir}/pari/pari.desc
%{_datadir}/applications/fedora-gp.desktop
%{_mandir}/man1/gp-2.5.1*
%{_mandir}/man1/gp.1*
%{_mandir}/man1/gphelp.1*
%{_mandir}/man1/pari.1*
%{_mandir}/man1/tex2mail.1*

%files devel
%{_includedir}/pari/
%{_libdir}/libpari.so

%changelog
* Fri Mar 08 2013 Igor Vlasenko <viy@altlinux.ru> 2.5.3-alt1_2
- update to new release by fcimport

* Tue Jan 15 2013 Igor Vlasenko <viy@altlinux.ru> 2.5.3-alt1_1
- initial fc import

* Tue May 23 2006 Alex V. Myltsev <avm@altlinux.ru> 2.3.0-alt1
- 2.3. This is a stable version of Pari.
- soname change.

* Wed May 03 2006 Alex V. Myltsev <avm@altlinux.ru> 2.2.13-alt1.beta
- New version: memory allocation cleanups, misc. bug fixes.

* Tue Jan 24 2006 Alex V. Myltsev <avm@altlinux.ru> 2.2.12-alt1.beta
- 2.2.12. Pari 2.2 is now in beta phase.

* Thu Oct 20 2005 Alex V. Myltsev <avm@altlinux.ru> 2.2.11-alt1.alpha
- 2.2.11 (bug fixes).
- emacs-pari is now packaged

* Mon Oct 03 2005 Alex V. Myltsev <avm@altlinux.ru> 2.2.10.alpha-alt2
- fixed textrel and runpath
- the assembler kernel is now disabled

* Sun Apr 24 2005 Alex V. Myltsev <avm@altlinux.ru> 2.2.10.alpha-alt1
- version 2.2.10.alpha

* Sat Mar 05 2005 Alex V. Myltsev <avm@altlinux.ru> 2.2.9.alpha-alt1
- ALT adaptation.

